@@ -4,11 +4,9 @@ import locale
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
-
-class CategoryPushButton(QPushButton):
-    def __init__(self, text, parent, jsonLink):
-        QPushButton.__init__(self, text, parent)
-        self.jsonLink = jsonLink
+from about_ui import Ui_AboutDialog
+from .. import version
+__version__ = version.__version__
 
 class MovieItemWidget(QFrame):
     def __init__(self, movie, trailerFilter, *args):
@@ -180,3 +178,12 @@ class PyTrailerSettings(QDialog):
             self.downloadPath.setText(directory)
 
 
+class PyTrailerAbout(QDialog):
+    def __init__(self, parent):
+        QDialog.__init__(self)
+        self.ui = Ui_AboutDialog()
+        self.ui.setupUi(self)
+        self._main  = parent
+        self.ui.label_version.setText(__version__)
+        self.connect(self.ui.buttonClose, SIGNAL("clicked(bool)"), self.close)
+
